@@ -24,14 +24,12 @@ def batch_records(
     max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
     min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
 ) -> List[Batch]:
-    batch_size = max_batch_size if max_batch_size else DEFAULT_MAX_BATCH_SIZE
-    min_common_dim = min_common_dimensions if min_common_dimensions else DEFAULT_MIN_COMMON_DIMENSIONS
     batches, remaining = [], records
     DEFAULT_LOGGER.info(f"MAX BATCH || {max_batch_size}  MIN COMMON DIM || {min_common_dimensions}")
     while len(remaining) > 0:
         DEFAULT_LOGGER.info(f"Remaining records to batch || {len(remaining)}")
         batch, remaining = _batch_records_helper(
-            remaining, batch_size, min_common_dim
+            remaining, max_batch_size, min_common_dimensions
         )
         batches.append(batch)
     return batches
